# Visualization

MDTerp provides four built-in visualization functions for analyzing results.

## Feature Importance Bar Plot

::: MDTerp.visualization.plot_feature_importance

## Importance Heatmap

::: MDTerp.visualization.plot_importance_heatmap

## Unfaithfulness Curve

::: MDTerp.visualization.plot_unfaithfulness_curve

## Per-Point Variability

::: MDTerp.visualization.plot_point_variability
